#!/usr/bin/perl -w
#
#     
#
#   example        
#\begin{example}[0.3\textwidth]{latin-design}
#    ,   \    % -   
#      %begin  %end
#   example    , 
#  .      %precommand.
#
# :
#%precommand \newlength{\MyLen}
#\begin{example}[0.4\textwidth]{length-ex-and-em}
#\setlength{\MyLen}{1ex}
# x  \the\MyLen\par
#\Large \setlength{\MyLen}{1ex}
# x  \the\MyLen
#\end{example}
#
#%begin{example}{tab-greek}
#\begin{table}[htbp]
#  \label{tab:math:greek}
#  \centering
#  \begin{tabular}{clclclclcl}\hline
#
#  \end{tabular}
#\end{table}
#%end{example}
#
#  :
#
#./example.pl -i math.tex -d math-doc/
#
#   math-doc/      ,   
#  "file exist Overwrite (yes/NO/all)" 
#
# TODO    
#            
#  ޣ -  -   
#        BoundingBox (origin=) -    
# gs -q -dSAFER -dNOPAUSE -dBATCH -sDEVICE=bbox
#  ps2eps -B -l (?)  
#
use Getopt::Std;
use File::stat;
use Term::ReadLine;
use Time::Local;
use File::Basename;
use POSIX;
use POSIX qw(:sys_wait_h);

getopts("hi:d:p:e:");
use vars qw/$opt_h  $opt_i $opt_d $opt_p $opt_e/;

$LaTeXbin="/usr/local/bin/latex";
$dvipsbin="/usr/local/bin/dvips";

if (defined($opt_h)||!defined($opt_i)||!defined($opt_d)) {
  print "Usage: $0 [-h] -i <file> -d <dir> [-p <file>] [-e <file>]\n";
  print "Options: -h - help message\n";
  print "         -i <file> - input file\n";
  print "         -d <file> - output dir\n";
  print "         -p <file> - preheader\n";
  print "         -e <file> - example.sty\n";
  exit();
}
unless (defined($opt_p)) {$opt_p="preheader.tex";}
unless (defined($opt_e)) {$opt_e="example.sty";}
# 
system("mkdir -p $opt_d");
#,        
#,  
$dirname = dirname($opt_i);
open (SYS,"cd $dirname;pwd|");$basedir=<SYS>;close(SYS);chomp $basedir;
$TEXINPUTS="TEXINPUTS=./:$basedir: ";
$LaTeXbin=$TEXINPUTS.$LaTeXbin;
$dvipsbin=$TEXINPUTS.$dvipsbin;

# table -    ݣ -
open(INPUT,"<$opt_i") or die "Couldn't open input-file $opt_i $!\n";


my $term= Term::ReadLine->new("Simple Terminal");my $cmd=();
my $OVERWRITE=0;

open(INPUT,"<$opt_i") or die "Couldn't open input-file $opt_i $!\n";

while ($str=<INPUT>) {
  if ($str=~m/^(%)precommand(.*)$/) {$precommand.="$2\n";}
  if ($str=~m/^\s*(\\|%)begin\{example\}.*\{\s*([^\s]*)\s*\}/) {
    $prefix=$1;
    if ($prefix eq "\\") {$prefix="\\\\";} 
    $file=$2;
    #  
    if ($OVERWRITE==0&&open(CHECK,"<$opt_d/$file.eps")) {
      $cmd=$term->readline("$file.eps exist Overwrite (yes/NO/all/skip): ");
      if (lc($cmd) eq "all") {$OVERWRITE=1;}
      elsif ((lc($cmd) eq "skip") || (lc($cmd) eq "s")) {
	close(CHECK);next;
      }
      elsif (lc($cmd) ne "yes") {
	die "file $opt_d/$file.eps exist - should be deleted\n";}
      close(CHECK);
    }
    #    
    open(OUTPUT,">$opt_d/$file.tex") or 
      die "Couldn't open ouput-file $opt_d/$file.tex $!\n";
    print OUTPUT "\\input{preheader}\n";
    print OUTPUT "\\begin{document}\n";
    print OUTPUT "\\thispagestyle{empty}\n";
    print OUTPUT "$precommand";$precommand="";
    print OUTPUT $str;
    #   
    while ($str=<INPUT>) {
      print OUTPUT $str;
      #    
      if ($str=~m/^\s*($prefix)end\{example\}/) { last; }
    }
    print OUTPUT "\\end{document}\n";
    close(OUTPUT) or die "Couldn't close file $opt_d/$file.tex $!\n";
    system("cd $opt_d; $LaTeXbin $file");
    system("cd $opt_d; $dvipsbin -E $file -o $file.eps");
  }
}

close(INPUT) or die "Couldn't close input-file $opt_i $!\n";

